Name: libtalloc
Version: 2.2.0
Release: 9%{?dist}
Group: System Environment/Daemons
Summary: The talloc library
License: LGPLv3+
URL: https://talloc.samba.org/
Source: https://www.samba.org/ftp/talloc/talloc-%{version}.tar.gz

BuildRequires: gcc
BuildRequires: libxslt
BuildRequires: docbook-style-xsl
BuildRequires: python3-devel
BuildRequires: doxygen

Provides: bundled(libreplace)
Obsoletes: python2-talloc < %{version}-%{release}
Obsoletes: python2-talloc-devel < %{version}-%{release}
Obsoletes: python2-talloc-debuginfo < %{version}-%{release}

# Patches
Patch0001: py3_abi.patch

%description
A library that implements a hierarchical allocator with destructors.

%package devel
Group: Development/Libraries
Summary: Developer tools for the Talloc library
Requires: libtalloc = %{version}-%{release}

%description devel
Header files needed to develop programs that link against the Talloc library.

%package -n python3-talloc
Group: Development/Libraries
Summary: Python bindings for the Talloc library
Requires: libtalloc = %{version}-%{release}
Obsoletes: pytalloc < %{version}-%{release}
%{?python_provide:%python_provide python3-talloc}

%description -n python3-talloc
Python 3 libraries for creating bindings using talloc

%package -n python3-talloc-devel
Group: Development/Libraries
Summary: Development libraries for python3-talloc
Requires: python3-talloc = %{version}-%{release}
Obsoletes: pytalloc-devel < %{version}-%{release}
%{?python_provide:%python_provide python3-talloc-devel}

%description -n python3-talloc-devel
Development libraries for python3-talloc

%prep
%autosetup -n talloc-%{version} -p1

%build

# workaround for https://bugzilla.redhat.com/show_bug.cgi?id=1217376
export python_LDFLAGS=""

%configure --disable-rpath \
           --disable-rpath-install \
           --bundled-libraries=NONE \
           --builtin-libraries=replace \
           --disable-silent-rules \

make %{?_smp_mflags} V=1
doxygen doxy.config

%check
make %{?_smp_mflags} check

%install
make install DESTDIR=$RPM_BUILD_ROOT

# Shared libraries need to be marked executable for
# rpmbuild to strip them and include them in debuginfo
find $RPM_BUILD_ROOT -name "*.so*" -exec chmod -c +x {} \;

rm -f $RPM_BUILD_ROOT%{_libdir}/libtalloc.a
rm -f $RPM_BUILD_ROOT/usr/share/swig/*/talloc.i

# Install API docs
cp -a doc/man/* $RPM_BUILD_ROOT/%{_mandir}

%files
%{_libdir}/libtalloc.so.*

%files devel
%{_includedir}/talloc.h
%{_libdir}/libtalloc.so
%{_libdir}/pkgconfig/talloc.pc
%{_mandir}/man3/talloc*.3.gz
%{_mandir}/man3/libtalloc*.3.gz

%files -n python3-talloc
%{_libdir}/libpytalloc-util.cpython*.so.*
%{python3_sitearch}/talloc.cpython*.so

%files -n python3-talloc-devel
%{_includedir}/pytalloc.h
%{_libdir}/pkgconfig/pytalloc-util.cpython-*.pc
%{_libdir}/libpytalloc-util.cpython*.so

%if %{defined rhel} && %{rhel} >= 8
%ldconfig_scriptlets
%ldconfig_scriptlets -n python3-talloc
%else
%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%post -n python3-talloc -p /sbin/ldconfig
%postun -n python3-talloc -p /sbin/ldconfig
%endif

%changelog
* Tue Feb 18 2020 Anoop C S <anoopcs@rehdat.com> - 2.2.0-9
- Remove already present pytalloc while installing python3-talloc
- Resolves: #1804165

* Thu Feb 13 2020 Anoop C S <anoopcs@redhat.com> - 2.2.0-8
- Remove unused variable
- Resolves: #1796074, #1796075

* Thu Jan 30 2020 Guenther Deschner <gdeschner@redhat.com> - 2.2.0-7
- Rebase to libtalloc 2.2.0
- Resolves: #1796074, #1796075

* Fri May 24 2019 Guenther Deschner <gdeschner@redhat.com> - 2.1.14-2
- Rebase to libtalloc 2.1.14
- Related: #1708289, #1708290

* Mon Feb 05 2018 Anoop C S <anoopcs@redhat.com> - 2.1.10-4
- Update to version 2.1.10
- Related: #1541919, #1541920

* Fri Mar 24 2017 Guenther Deschner <gdeschner@redhat.com> - 2.1.9-1
- New version from upstream
- Related: #1428989, #1426663

* Fri Mar 18 2016 Jose A. Rivera <jarrpa@redhat.com> - 2.1.6-1
- Update to version 2.1.6
- Related: #1318624

* Fri Oct 09 2015 Guenther Deschner <gdeschner@redhat.com> - 2.1.2-1
- New version from upstream.
- Related: #1269864

* Tue Apr 07 2015 Jose A. Rivera <jarrpa@redhat.com> - 2.1.1-4
- Rebuild for RHS 3.1

* Mon Mar 02 2015 Jose A. Rivera <jarrpa@redhat.com> - 2.1.1-3
- Remove conflicting dependencies
- Related: bug 1177341

* Wed Nov 05 2014 Jose A. Rivera <jarrpa@redhat.com> - 2.1.1-2
- Update conflicting dependencies

* Fri Aug 29 2014 Jose A. Rivera <jarrpa@redhat.com> - 2.1.1-1
- New version from upstream.

* Mon Oct  8 2012 Jakub Hrozek <jhrozek@redhat.com> - 2.0.7-2
- Obsolete older pytalloc{,-devel} releases to clear the upgrade path
  towards non-multilib pytalloc
- Resolves: rhbz#862062

* Thu Aug 2  2012 Jakub Hrozek <jhrozek@redhat.com> - 2.0.7-1
- New upstream version, resolves rhbz #766335
- Build python bindings to satisfy Samba4 BuildRequires

* Tue Dec 15 2009 Simo Sorce <ssorce@redhat.com> - 2.0.1-1.1
- New version from upstream
- Also stop building the compat lib, it is not necessary anymore

* Tue Sep  8 2009 Simo Sorce <ssorce@redhat.com> - 2.0.0-0
- New version from upstream.
- Build also sover 1 compat library to ease packages migration

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Jun 17 2009 Simo Sorce <ssorce@redhat.com> - 1.3.1-1
- Original tarballs had a screw-up, rebuild with new fixed tarballs from
  upstream.

* Tue Jun 16 2009 Simo Sorce <ssorce@redhat.com> - 1.3.1-0
- New Upstream release.

* Wed May 6 2009 Simo Sorce <ssorce@redhat.com> - 1.3.0-0
- First public independent release from upstream
